Module stable

Module stable 

Contains all items that are considered stable ABI and are safe to use. These items are intentionally opaque to prevent accidental compatibility issues.

If you need to access the internals of these items, please open an issue.

Structs

RArray

RData

RString

RTypedData

rb_internal_thread_event_data

rb_io_internal_buffer

rb_matchext_struct