#[repr(u32)]pub enum rb_warning_category_t {
RB_WARN_CATEGORY_NONE = 0,
RB_WARN_CATEGORY_DEPRECATED = 1,
RB_WARN_CATEGORY_EXPERIMENTAL = 2,
RB_WARN_CATEGORY_PERFORMANCE = 3,
RB_WARN_CATEGORY_DEFAULT_BITS = 6,
RB_WARN_CATEGORY_ALL_BITS = 14,
}Expand description
Warning categories. A warning issued using this API can be selectively
requested / suppressed by the end-users. For instance passing
-W:no-deprecated to the ruby process would suppress those warnings in
deprecated category.
@warning There is no way to declare a new category (for now).
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
Variants
RB_WARN_CATEGORY_NONE = 0
RB_WARN_CATEGORY_DEPRECATED = 1
RB_WARN_CATEGORY_EXPERIMENTAL = 2
RB_WARN_CATEGORY_PERFORMANCE = 3
Warning is for performance issues (not enabled by -w).
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
RB_WARN_CATEGORY_DEFAULT_BITS = 6
Warning is for performance issues (not enabled by -w).
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
RB_WARN_CATEGORY_ALL_BITS = 14