rb_backref_set

Function rb_backref_set 

pub unsafe extern "C" fn rb_backref_set(md: VALUE)
Updates $~. You don’t have to use it, because in reality you can set $~ using rb_gv_set as usual.

@param[in] md Arbitrary Ruby object. @post The passed object is assigned to $~.

@internal

Yes, this function bypasses the Check_Type() that would normally prevent evil souls from assigning evil objects to $~. Use of this function is a really bad smell.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8