rb_mod_remove_const

Function rb_mod_remove_const 

pub unsafe extern "C" fn rb_mod_remove_const(
    space: VALUE,
    name: VALUE,
) -> VALUE
Resembles Module#remove_const.

@param[out] space Target namespace. @param[in] name Variable name to remove, either in Symbol or String. @return What was removed. @pre Constant named space::name is deleted. @note In case what was removed was in fact a module or a class, this operation does not affect its name. Which means when people for instance look at it using p etc., it still introduces itself using the deleted name. Can confuse people.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8