rb_profile_thread_frames

Function rb_profile_thread_frames 

pub unsafe extern "C" fn rb_profile_thread_frames(
    thread: VALUE,
    start: c_int,
    limit: c_int,
    buff: *mut VALUE,
    lines: *mut c_int,
) -> c_int
Queries mysterious “frame“s of the given range.

A per-thread version of rb_profile_frames. Arguments and return values are the same with rb_profile_frames with the exception of the first argument thread, which accepts the Thread to be profiled/queried.

@param[in] thread The Ruby Thread to be profiled. @param[in] start Start position (0 means the topmost). @param[in] limit Number objects of buff. @param[out] buff Return buffer. @param[out] lines Return buffer. @return Number of objects filled into buff. @post buff is filled with backtrace pointers. @post lines is filled with __LINE__ of each backtraces.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8