rb_str_modify

Function rb_str_modify 

pub unsafe extern "C" fn rb_str_modify(str_: VALUE)
Declares that the string is about to be modified. This for instance let the string have a dedicated backend storage.

@param[out] str String about to be modified. @exception rb_eRuntimeError str is locktmp-ed. @exception rb_eFrozenError str is frozen. @pre str must not be any arbitrary objects except ::RString. @post Upon successful return the passed string is eligible to be modified.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8