rb_thread_fd_close

Function rb_thread_fd_close 

pub unsafe extern "C" fn rb_thread_fd_close(fd: c_int)
Notifies a closing of a file descriptor to other threads. Multiple threads can wait for the given file descriptor at once. If such file descriptor is closed, threads need to start propagating their exceptions. This is the API to kick that process.

@param[in] fd A file descriptor. @note This function blocks until all the threads waiting for such fd have woken up.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8