rb_thread_remove_event_hook_with_data

Function rb_thread_remove_event_hook_with_data 

pub unsafe extern "C" fn rb_thread_remove_event_hook_with_data(
    thval: VALUE,
    func: rb_event_hook_func_t,
    data: VALUE,
) -> c_int
Identical to rb_thread_remove_event_hook, except it additionally takes the data argument. It can also be seen as a routine identical to rb_remove_event_hook_with_data, except it additionally takes the thread. This function deletes hooks that satisfy all three criteria.

@param[in] thval An instance of ::rb_cThread. @param[in] func A callback. @param[in] data What to be passed to func. @exception rb_eTypeError thval is not a thread. @return Number of deleted event hooks. @note As multiple events can share the same func it is quite possible for the return value to become more than one.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8