rb_warning

Function rb_warning 

pub unsafe extern "C" fn rb_warning(fmt: *const c_char, ...)
Issues a warning.

In ruby, warnings these days are tightly coupled with the [rb_mWarning] constant and its warn singleton method. This CAPI is just a thin wrapper of it; everything passed are formatted like what rb_sprintf does, then passed through to the method. Programs can have their own def Warning.warn at will to do whatever they want, from ignoring the warnings at all to sinking them to some BigQuery data set via a Fluentd cluster. By default, the method just emits its passed contents to ::rb_stderr using rb_io_write.

@note This function is affected by the value of $VERBOSE, it does nothing unless $VERBOSE is true. @param[in] fmt Format specifier string compatible with rb_sprintf.

@internal

Above description is in fact inaccurate. This API interfaces with Ractors.

Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8