#[repr(C)]pub struct RObject__bindgen_ty_1__bindgen_ty_1 {
pub ivptr: *mut VALUE,
pub iv_index_tbl: *mut rb_id_table,
}Expand description
Fields
ivptr: *mut VALUEPointer to a C array that holds instance variables.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
iv_index_tbl: *mut rb_id_tableThis is a table that holds instance variable name to index mapping. Used when accessing instance variables using names.
@internal
This is a shortcut for RCLASS_IV_INDEX_TBL([rb_obj_class]obj)).
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8