#[repr(C)]pub struct RString__bindgen_ty_1__bindgen_ty_1 {
pub ptr: *mut c_char,
pub aux: RString__bindgen_ty_1__bindgen_ty_1__bindgen_ty_1,
}Expand description
Fields
ptr: *mut c_charPointer to the contents of the string. In the old days each string had dedicated memory regions. That is no longer true today, but there still are strings of such properties. This field could be used to point such things.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
aux: RString__bindgen_ty_1__bindgen_ty_1__bindgen_ty_1Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8