#[repr(C)]pub struct rb_internal_thread_event_data {
pub thread: VALUE,
}To improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
Fields
thread: VALUETo improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8