#[repr(C)]pub struct rb_matchext_struct {
pub regs: re_registers,
pub char_offset: *mut rmatch_offset,
pub char_offset_num_allocated: c_int,
}To improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
Fields
regs: re_registersTo improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
โRegistersโ of a match. This is a quasi-opaque struct that holds
execution result of a match. Roughly resembles &~.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8
char_offset: *mut rmatch_offsetTo improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
char_offset_num_allocated: c_intTo improve API stability with ruby-head, direct usage of Ruby internal structs has been deprecated. To migrate, please replace the usage of this internal struct with its counterpart in the rb_sys::stable module. For example, instead of use rb_sys::rb_sys__Opaque__ExampleStruct;, use use rb_sys::stable::ExampleStruct;. If you need to access the internals of these items, you can use the provided rb-sys::macros instead.
Number of ::rmatch_offset that ::rmatch::char_offset holds.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8