RARRAY_ASET

Function RARRAY_ASET 

pub unsafe fn RARRAY_ASET(obj: VALUE, idx: isize, val: VALUE)
Write array element at index (akin to RARRAY_ASET).

This function includes the GC write barrier for correctness.

Safety

This function is unsafe because it dereferences a raw pointer in order to access internal Ruby memory.

  • @param[in] obj An object of ::RArray.
  • @param[in] idx Index within the array (must be within bounds: 0..RARRAY_LEN(obj)).
  • @param[in] val The value to set at the given index.