RTYPEDDATA_GET_DATA

Function RTYPEDDATA_GET_DATA 

pub unsafe fn RTYPEDDATA_GET_DATA(obj: VALUE) -> *mut c_void
Gets the data pointer from an RTypedData object.

@param[in] obj An RTypedData object. @return Pointer to the wrapped C struct.

Safety

This function is unsafe because it dereferences a raw pointer to get access to the underlying data. The caller must ensure the object is a valid RTypedData.