RTYPEDDATA_P

Function RTYPEDDATA_P 

pub unsafe fn RTYPEDDATA_P(obj: VALUE) -> bool
Checks if the given object is an RTypedData.

@param[in] obj Object in question. @retval true It is an RTypedData. @retval false It isn’t an RTypedData.

Safety

This function is unsafe because it could dereference a raw pointer when accessing the underlying data structure.