pub unsafe extern "C" fn rb_str_drop_bytes(
str_: VALUE,
len: c_long,
) -> VALUEExpand description
Shrinks the given string for the given number of bytes.
@param[out] str String to squash.
@param[in] len Number of bytes to reduce.
@exception rb_eRuntimeError str is locktmp-ed.
@exception rb_eFrozenError str is frozen.
@return The passed str.
@pre str must not be any arbitrary objects except ::RString.
@post str is shrunken.
@warning Can break a multibyte character in middle.
@internal
What if len is negative?
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8