pub unsafe extern "C" fn rb_str_subseq(
str_: VALUE,
beg: c_long,
len: c_long,
) -> VALUEExpand description
Identical to rb_str_substr, except the numbers are interpreted as byte
offsets instead of character offsets.
@param[in] str The string to slice.
@param[in] beg Requested offset of the substring.
@param[in] len Requested length of the substring.
@return A new string whose contents is the specified substring of str.
@pre str must not be any arbitrary objects except ::RString.
@pre beg and len must not point to OOB contents.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8