pub unsafe extern "C" fn rb_thread_main() -> VALUEExpand description
Obtains the “main” thread. There are threads called main. Historically the (only) main thread was the one which runs when the process boots. Now that we have Ractor, there are more than one main threads.
@return The main thread of the current ractor of the current execution context. @pre This function must be called from a thread controlled by ruby.
Generated by rb-sys for Ruby mri-x86_64-linux-gnu-3.3.8